@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_COMMAND_H
-#define AKREGATOR_COMMAND_H
+#pragma once
 
 #include "akregatorinterfaces_export.h"
 
@@ -49,4 +48,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_COMMAND_H
