@@ -87,7 +87,7 @@ public:
     }
 
 private:
-    ActionManagerImpl *m_manager = nullptr;
+    ActionManagerImpl *const m_manager;
 };
 
 class ActionManagerImpl::ActionManagerImplPrivate
@@ -117,6 +117,13 @@ void ActionManagerImpl::slotSettingsChanged()
     }
     a->setChecked(Settings::hideReadFeeds());
 
+    a = action(QStringLiteral("feed_lock_in_place"));
+    if (!a) {
+        qCCritical(AKREGATOR_LOG) << "Action not found";
+        return;
+    }
+    a->setChecked(Settings::lockFeedsInPlace());
+
     a = action(QStringLiteral("auto_expand_folders"));
     if (!a) {
         qCCritical(AKREGATOR_LOG) << "Action not found";
@@ -307,7 +314,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     coll->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_R));
 
     // Settings menu
-    auto *sqf = coll->add<KToggleAction>(QStringLiteral("show_quick_filter"));
+    auto sqf = coll->add<KToggleAction>(QStringLiteral("show_quick_filter"));
     sqf->setText(i18n("Show Quick Filter"));
     connect(sqf, &QAction::triggered, d->mainWidget, &MainWidget::slotToggleShowQuickFilter);
     sqf->setChecked(Settings::showQuickFilter());
@@ -354,7 +361,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     connect(action, &QAction::triggered, d->mainWidget, &MainWidget::slotArticleDelete);
     coll->setDefaultShortcut(action, QKeySequence(Qt::Key_Delete));
 
-    auto *statusMenu = coll->add<KActionMenu>(QStringLiteral("article_set_status"));
+    auto statusMenu = coll->add<KActionMenu>(QStringLiteral("article_set_status"));
     statusMenu->setText(i18n("&Mark As"));
     statusMenu->setEnabled(false);
 
@@ -382,7 +389,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     connect(action, &QAction::triggered, d->mainWidget, &MainWidget::slotSetSelectedArticleUnread);
     statusMenu->addAction(action);
 
-    auto *importantAction = coll->add<KToggleAction>(QStringLiteral("article_set_status_important"));
+    auto importantAction = coll->add<KToggleAction>(QStringLiteral("article_set_status_important"));
     importantAction->setText(i18n("&Mark as Important"));
     importantAction->setIcon(QIcon::fromTheme(QStringLiteral("mail-mark-important")));
     const QList<QKeySequence> importantSC = {QKeySequence(Qt::CTRL | Qt::Key_I), QKeySequence(Qt::Key_I)};
@@ -529,6 +536,12 @@ void ActionManagerImpl::initSubscriptionListView(SubscriptionListView *subscript
     action->setChecked(Settings::hideReadFeeds());
     connect(action, &QAction::triggered, subscriptionListView, &SubscriptionListView::slotSetHideReadFeeds);
 
+    action = coll->addAction(QStringLiteral("feed_lock_in_place"));
+    action->setCheckable(true);
+    action->setText(i18n("Lock Feeds In Place"));
+    action->setChecked(Settings::lockFeedsInPlace());
+    connect(action, &QAction::triggered, subscriptionListView, &SubscriptionListView::slotSetLockFeedsInPlace);
+
     action = coll->addAction(QStringLiteral("auto_expand_folders"));
     action->setCheckable(true);
     action->setText(i18n("Auto-expand folders with unread articles"));
