@@ -37,6 +37,9 @@
 #include <QWebEngineUrlRequestInterceptor>
 #include <viewerplugintoolmanager.h>
 
+#include <WebEngineViewer/BlockExternalResourcesUrlInterceptor>
+#include <WebEngineViewer/BlockTrackingUrlInterceptor>
+#include <WebEngineViewer/LoadExternalReferencesUrlInterceptor>
 #include <WebEngineViewer/WebEngineScript>
 #include <WebEngineViewer/WebHitTest>
 #include <WebEngineViewer/WebHitTestResult>
@@ -62,24 +65,38 @@ public:
         Q_UNUSED(info)
     }
 };
-
+#define HAVE_BLOCK_SUPPORT 1
 ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *parent)
     : WebEngineViewer::WebEngineView(parent)
     , mActionCollection(ac)
 {
+#ifndef HAVE_BLOCK_SUPPORT
     mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
-
+#endif
     mPageEngine = new ArticleViewerWebEnginePage(this);
     QWebEngineProfile *profile = mPageEngine->profile();
     profile->setPersistentCookiesPolicy(QWebEngineProfile::ForcePersistentCookies);
-
+#ifndef HAVE_BLOCK_SUPPORT
     // Needed to workaround crash in webengine, see https://bugreports.qt.io/browse/QTBUG-72260
     auto webEngineUrlInterceptor = new AkregatorRequestInterceptor();
     connect(profile, &QObject::destroyed, webEngineUrlInterceptor, &AkregatorRequestInterceptor::deleteLater);
     profile->setUrlRequestInterceptor(webEngineUrlInterceptor);
-
+#endif
     setPage(mPageEngine);
 
+#ifdef HAVE_BLOCK_SUPPORT
+    mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
+    mExternalReference = new WebEngineViewer::LoadExternalReferencesUrlInterceptor(this);
+    mExternalReference->setAllowExternalContent(Settings::self()->loadExternalReferences());
+    // connect(externalReference, &MessageViewer::LoadExternalReferencesUrlInterceptor::urlBlocked, this, &MailWebEngineView::urlBlocked);
+    mNetworkAccessManager->addInterceptor(mExternalReference);
+    auto blockTracking = new WebEngineViewer::BlockTrackingUrlInterceptor(this);
+    connect(blockTracking, &WebEngineViewer::BlockTrackingUrlInterceptor::trackingFound, this, &ArticleViewerWebEngine::trackingFound);
+    mNetworkAccessManager->addInterceptor(blockTracking);
+    mBlockExternalReference = new WebEngineViewer::BlockExternalResourcesUrlInterceptor(this);
+    // TODO connect(mBlockExternalReference, &WebEngineViewer::BlockExternalResourcesUrlInterceptor::formSubmittedForbidden, this,
+    // &MailWebEngineView::urlBlocked);
+#endif
     connect(this, &ArticleViewerWebEngine::showContextMenu, this, &ArticleViewerWebEngine::slotShowContextMenu);
 
     setFocusPolicy(Qt::WheelFocus);
@@ -114,6 +131,11 @@ void ArticleViewerWebEngine::execPrintPreviewPage(QPrinter *printer, int timeout
     }
 }
 
+void ArticleViewerWebEngine::updateSecurity()
+{
+    mExternalReference->setAllowExternalContent(Settings::self()->loadExternalReferences());
+}
+
 void ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged()
 {
     Q_EMIT webPageMutedOrAudibleChanged(page()->isAudioMuted(), page()->recentlyAudible());
@@ -162,7 +184,7 @@ void ArticleViewerWebEngine::slotSaveLinkAs()
         url.setPath(url.path() + QLatin1String("/index.html"));
     }
 
-    QFileDialog *dlg = new QFileDialog(this);
+    auto dlg = new QFileDialog(this);
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setAcceptMode(QFileDialog::AcceptSave);
     dlg->setWindowTitle(i18n("Save As"));
