@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_CREATEFOLDERCOMMAND_H
-#define AKREGATOR_CREATEFOLDERCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -38,4 +37,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_CREATEFOLDERCOMMAND_H
