@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_LOADFEEDLISTCOMMAND_H
-#define AKREGATOR_LOADFEEDLISTCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -48,4 +47,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_LOADFEEDLISTCOMMAND_H
