@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_FEED_H
-#define AKREGATOR_FEED_H
+#pragma once
 
 #include "akregator_export.h"
 #include "treenode.h"
@@ -301,4 +300,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_FEED_H
