@@ -20,7 +20,9 @@
 #include <QMenu>
 #include <QWebEngineHistory>
 #include <QWebEngineSettings>
+#include <WebEngineViewer/BlockExternalResourcesUrlInterceptor>
 #include <WebEngineViewer/InterceptorManager>
+#include <WebEngineViewer/LoadExternalReferencesUrlInterceptor>
 #include <WebEngineViewer/WebHitTest>
 #include <WebEngineViewer/WebHitTestResult>
 
@@ -29,6 +31,12 @@ using namespace Akregator;
 AkrWebEngineViewer::AkrWebEngineViewer(KActionCollection *ac, QWidget *parent)
     : ArticleViewerWebEngine(ac, parent)
 {
+    if (mExternalReference) {
+        mExternalReference->setAllowExternalContent(true);
+    }
+    if (mBlockExternalReference) { // Don't block element
+        mBlockExternalReference->setEnabled(false);
+    }
     // TODO update settings when we change config
     settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, Settings::enableJavascript());
     settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
@@ -48,6 +56,11 @@ AkrWebEngineViewer::~AkrWebEngineViewer()
 {
 }
 
+void AkrWebEngineViewer::updateSecurity()
+{
+    // Nothing
+}
+
 void AkrWebEngineViewer::contextMenuEvent(QContextMenuEvent *e)
 {
     displayContextMenu(e->pos());
