@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,32 +17,28 @@ using namespace Akregator;
 WebEngineFrame::WebEngineFrame(KActionCollection *ac, QWidget *parent)
     : Frame(parent)
 {
-    auto *layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto layout = new QVBoxLayout(this);
+    layout->setContentsMargins({});
     setRemovable(true);
-    auto *viewer = new Akregator::AkrWebEngineViewer(ac, this);
+    auto viewer = new Akregator::AkrWebEngineViewer(ac, this);
     mArticleViewerWidgetNg = new Akregator::ArticleViewerWebEngineWidgetNg(viewer, ac, this);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::titleChanged,
-            this, &WebEngineFrame::slotTitleChanged);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::titleChanged, this, &WebEngineFrame::slotTitleChanged);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadProgress,
-            this, &WebEngineFrame::slotProgressChanged);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadProgress, this, &WebEngineFrame::slotProgressChanged);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::signalOpenUrlRequest,
-            this, &WebEngineFrame::signalOpenUrlRequest);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::signalOpenUrlRequest, this, &WebEngineFrame::signalOpenUrlRequest);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadStarted,
-            this, &WebEngineFrame::slotLoadStarted);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadStarted, this, &WebEngineFrame::slotLoadStarted);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadFinished,
-            this, &WebEngineFrame::slotLoadFinished);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::loadFinished, this, &WebEngineFrame::slotLoadFinished);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::showStatusBarMessage,
-            this, &WebEngineFrame::showStatusBarMessage);
+    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::showStatusBarMessage, this, &WebEngineFrame::showStatusBarMessage);
 
-    connect(mArticleViewerWidgetNg->articleViewerNg(), &ArticleViewerWebEngine::webPageMutedOrAudibleChanged,
-            this, &WebEngineFrame::slotWebPageMutedOrAudibleChanged);
+    connect(mArticleViewerWidgetNg->articleViewerNg(),
+            &ArticleViewerWebEngine::webPageMutedOrAudibleChanged,
+            this,
+            &WebEngineFrame::slotWebPageMutedOrAudibleChanged);
 
     layout->addWidget(mArticleViewerWidgetNg);
 }
@@ -83,7 +79,7 @@ QUrl WebEngineFrame::url() const
 
 void WebEngineFrame::loadUrl(const QUrl &url)
 {
-    auto *job = new KIO::FavIconRequestJob(url);
+    auto job = new KIO::FavIconRequestJob(url);
     connect(job, &KIO::FavIconRequestJob::result, this, [job, this](KJob *) {
         if (!job->error()) {
             Q_EMIT signalIconChanged(this, QIcon(job->iconFile()));
