@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_NOTIFICATIONMANAGER_H
-#define AKREGATOR_NOTIFICATIONMANAGER_H
+#pragma once
 
 #include <QObject>
 #include <QVector>
@@ -25,7 +24,7 @@ public:
     /** singleton instance of notification manager */
     static NotificationManager *self();
 
-    ~NotificationManager();
+    ~NotificationManager() override;
 
     /** the widget used for notification, normally either the mainwindow or the tray icon */
     void setWidget(QWidget *widget, const QString &componentName = QString());
@@ -68,4 +67,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_NOTIFICATIONMANAGER_H
